"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const class_transformer_1 = require("class-transformer");
/*
|--------------------------------------------------------------------------
| Provider
|--------------------------------------------------------------------------
|
| Your application is not ready when this file is loaded by the framework.
| Hence, the top level imports relying on the IoC container will not work.
| You must import them inside the life-cycle methods defined inside
| the provider class.
|
| @example:
|
| public async ready () {
|   const Database = (await import('@ioc:Adonis/Lucid/Database')).default
|   const Event = (await import('@ioc:Adonis/Core/Event')).default
|   Event.on('db:query', Database.prettyPrint)
| }
|
*/
class ClassValidatorProvider {
    constructor(app) {
        this.app = app;
    }
    boot() {
        return __awaiter(this, void 0, void 0, function* () {
            this.bindClassValidator();
            this.registerRequestMacro();
        });
    }
    /**
     * Bind the class validator to the IOC.
     */
    bindClassValidator() {
        const adonisValidator = this.app.container.use("Adonis/Core/Validator");
        this.app.container.singleton("Adonis/ClassValidator", () => {
            return Object.assign({ validate: require("../src").validate }, adonisValidator);
        });
    }
    /**
     * Register the `classValidate(...)` macros to the Request instance.
     */
    registerRequestMacro() {
        const { schema } = this.app.container.use("Adonis/Core/Validator");
        this.app.container.withBindings(["Adonis/Core/Request"], (request) => {
            const { getValidatorBag } = require("../src");
            request.macro("classValidate", function classValidate(validatorClass, args) {
                return __awaiter(this, void 0, void 0, function* () {
                    const validatorBag = getValidatorBag(validatorClass);
                    const data = yield this.validate(Object.assign({ schema: schema.create(validatorBag.schema), cacheKey: validatorBag.key }, args));
                    return class_transformer_1.plainToClass(validatorClass, data);
                });
            });
        });
    }
}
exports.default = ClassValidatorProvider;
ClassValidatorProvider.needsApplication = true;
