"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validate = void 0;
const utils_1 = require("./utils");
const class_transformer_1 = require("class-transformer");
const luxon_1 = require("luxon");
/**
 * Validate a decorated field in a class.
 * @param schema Adonis validation schema for field.
 * @param messages Custom messages for field
 * @returns void
 */
const validate = (schema, messages) => {
    return function (target, propertyKey) {
        const validatorBag = utils_1.getValidatorBag(target);
        validatorBag.schema[propertyKey] = schema;
        validatorBag.messages = Object.assign(Object.assign({}, validatorBag.messages), (messages ? utils_1.transformMessages(propertyKey, messages) : {}));
        if (utils_1.schemaIsDate(schema)) {
            class_transformer_1.Type(() => String)(target, propertyKey);
            class_transformer_1.Transform(({ value }) => luxon_1.DateTime.fromISO(value))(target, propertyKey);
        }
    };
};
exports.validate = validate;
/**
 * Validated a field with complex type using a custom validator class.
 * @param validatorClass Validator class to use for field.
 * @param schema Adonis validation schema
 * @param messages Custom messages for field.
 * @returns void
 */
exports.validate.nested = (validatorClass, schema, messages) => {
    return function (target, propertyKey) {
        const validatorBag = utils_1.getValidatorBag(target);
        const validatorSchema = schema(utils_1.nested(validatorClass));
        validatorBag.schema[propertyKey] = validatorSchema;
        const isArray = utils_1.schemaIsArray(validatorSchema);
        const validatorClassMessages = utils_1.getValidatorBag(validatorClass).messages;
        validatorBag.messages = Object.assign(Object.assign(Object.assign({}, validatorBag.messages), (messages ? utils_1.transformMessages(propertyKey, messages) : {})), utils_1.transformMessages(propertyKey, validatorClassMessages, isArray));
        // Initialize nested property for type casting to a class.
        class_transformer_1.Type(() => validatorClass)(target, propertyKey);
    };
};
